changeset 89538:c719d9f420d1

(char_string): Use ASCII_CHAR_P instead of SINGLE_BYTE_CHAR_P.
author Kenichi Handa <handa@m17n.org>
date Sun, 28 Sep 2003 23:54:27 +0000
parents a02c064cebec
children 681ad4b7421f
files src/character.c
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/character.c	Fri Sep 26 17:48:40 2003 +0000
+++ b/src/character.c	Sun Sep 28 23:54:27 2003 +0000
@@ -95,9 +95,9 @@
 
   if (c & CHAR_MODIFIER_MASK)
     {
-      /* As a character not less than 256 can't have modifier bits, we
-	 just ignore the bits.  */
-      if (SINGLE_BYTE_CHAR_P ((c & ~CHAR_MODIFIER_MASK)))
+      /* As an non-ASCII character can't have modifier bits, we just
+	 ignore the bits.  */
+      if (ASCII_CHAR_P ((c & ~CHAR_MODIFIER_MASK)))
 	{
 	  /* For Meta, Shift, and Control modifiers, we need special care.  */
 	  if (c & CHAR_META)